texlive_luatex: LuaTeX packages
===============================

Description
-----------

Packages for LuaTeX, a TeX engine using Lua as an embedded scripting and
extension language, with native support for Unicode, OpenType/TrueType fonts,
and both PDF and DVI output.

The purpose of this dummy package is to associate system package lists with it.

License
-------

GNU General Public License version 2.0 (GPLv2)

Upstream Contact
----------------

https://www.luatex.org/
